package org.apache.lucene.util.encoding;

import java.io.IOException;
import java.io.InputStream;

/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * An {@link IntDecoder} which wraps another {@link IntDecoder} and reverts the
 * d-gap that was encoded by {@link DGapIntEncoder}. The wrapped decoder
 * performs the actual decoding, while this class simply adds the decoded value
 * to the previous value.
 * 
 * @lucene.experimental
 */
public class DGapIntDecoder extends IntDecoder {

  private final IntDecoder decoder;

  private int prev = 0;

  public DGapIntDecoder(IntDecoder decoder) {
    this.decoder = decoder;
  }

  @Override
  public long decode() throws IOException {
    long decode = decoder.decode();
    if (decode == EOS) {
      return EOS;
    }

    return prev += decode;
  }

  @Override
  public void reInit(InputStream in) {
    decoder.reInit(in);
    prev = 0;
  }

  @Override
  public String toString() {
    return "DGap (" + decoder.toString() + ")";
  }

}
